==> highlight_2.2.6.orig.tar.gz: highlight-2.2.6/examples/python-binding/setup.py <==
from distutils.core import setup, Extension

ext = Extension('highlight',
#                define_macros = [('MAJOR_VERSION', '0'),
#                                 ('MINOR_VERSION', '3')],
                include_dirs = ['../../highlight'],
                #libraries = ['tcl83'],
                #library_dirs = ['../../highlight'],
                sources = ['highlightmodule.cpp', 
		           '../../highlight/latexgenerator.cpp',
			   '../../highlight/texgenerator.cpp',
			   '../../highlight/rtfgenerator.cpp',
			   '../../highlight/xslfogenerator.cpp',
			   '../../highlight/htmlgenerator.cpp',
			   '../../highlight/xhtmlgenerator.cpp',
                           '../../highlight/ansigenerator.cpp',
			   '../../highlight/codegenerator.cpp',
			   '../../highlight/documentstyle.cpp',
			   '../../highlight/elementstyle.cpp',
			   '../../highlight/stylecolour.cpp',
			   '../../highlight/ASBeautifier.cpp',
			   '../../highlight/ASFormatter.cpp',
			   '../../highlight/ASStreamIterator.cpp',
			   '../../highlight/ASResource.cpp',
			   '../../highlight/configurationreader.cpp',
			   '../../highlight/languagedefinition.cpp',
			   '../../highlight/linewrapper.cpp',
			   '../../highlight/stringtools.cpp'
			  ]
                )

setup (name = 'Highlight',
       version = '0.3',
       description = 'Highlight source generator converter',
       author = 'Andre Simon',
       author_email = 'andre.simon1@gmx.de',
       url = 'http://www.andre-simon.de/',
       long_description = '''
Extension for highlight, a universal source generator converter.
''',
       ext_modules = [ext])

==> highlight_2.2.8.orig.tar.gz: highlight-2.2.8/examples/python-binding/setup.py <==
from distutils.core import setup, Extension

ext = Extension('highlight',
#                define_macros = [('MAJOR_VERSION', '0'),
#                                 ('MINOR_VERSION', '3')],
                include_dirs = ['../../highlight'],
                #libraries = ['tcl83'],
                #library_dirs = ['../../highlight'],
                sources = ['highlightmodule.cpp', 
		           '../../highlight/latexgenerator.cpp',
			   '../../highlight/texgenerator.cpp',
			   '../../highlight/rtfgenerator.cpp',
			   '../../highlight/xslfogenerator.cpp',
			   '../../highlight/htmlgenerator.cpp',
			   '../../highlight/xhtmlgenerator.cpp',
                           '../../highlight/ansigenerator.cpp',
			   '../../highlight/xmlgenerator.cpp',			   
			   '../../highlight/codegenerator.cpp',
			   '../../highlight/documentstyle.cpp',
			   '../../highlight/elementstyle.cpp',
			   '../../highlight/stylecolour.cpp',
			   '../../highlight/ASBeautifier.cpp',
			   '../../highlight/ASFormatter.cpp',
			   '../../highlight/ASStreamIterator.cpp',
			   '../../highlight/ASResource.cpp',
			   '../../highlight/configurationreader.cpp',
			   '../../highlight/languagedefinition.cpp',
			   '../../highlight/preformatter.cpp',
			   '../../highlight/stringtools.cpp'
			  ]
                )

setup (name = 'Highlight',
       version = '0.5',
       description = 'Highlight source generator converter',
       author = 'Andre Simon',
       author_email = 'andre.simon1@gmx.de',
       url = 'http://www.andre-simon.de/',
       long_description = 'Extension for highlight, a universal source generator converter.',
       ext_modules = [ext])
